InSubqueryWhere class

column [not] in (select ...)

Inheritance

Constructors

InSubqueryWhere(Object column, QueryBuilder<Object?> query, String boolean, {required bool not})
const

Properties

boolean String
finalinherited
column Object
final
hashCode int
The hash code for this object.
no setterinherited
not bool
final
query QueryBuilder<Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited