JoinClause class

inner|left|right|cross join table on first op second.

Constructors

JoinClause(String type, String table, {Object? first, String? operator, Object? second})
const

Properties

first Object?
final
hashCode int
The hash code for this object.
no setterinherited
operator String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second Object?
final
table String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited