close method

Future<void> close()

Closes the database and forgets it as the default connection. Wire into tearDownAll when a suite shares its isolate with other database tests.

Implementation

Future<void> close() async {
  await _connection.close();
  DB.reset();
}